@@ -48,6 +48,8 @@ class BootDocker(Boot):
     def accepts(cls, device, parameters):
         if "docker" not in device['actions']['boot']['methods']:
             return False, '"docker" was not in the device configuration boot methods'
+        if parameters["method"] != "docker":
+            return False, '"method" was not "docker"'
         if "command" not in parameters:
             return False, '"command" was not in boot parameters'
         return True, 'accepted'
@@ -136,5 +138,5 @@ class CallDockerAction(Action):
         super().cleanup(connection)
         if self.cleanup_required:
             self.logger.debug("Stopping container %s", self.container)
-            self.run_command(["docker", "stop", self.container], allow_fail=True)
+            self.run_cmd(["docker", "stop", self.container], allow_fail=True)
             self.cleanup_required = False
