@@ -18,32 +18,14 @@
 # along
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
-from lava_dispatcher.action import (
-    Action,
-    JobError,
-)
+from lava_dispatcher.action import Action
+from lava_common.exceptions import LAVATimeoutError
 from lava_dispatcher.logical import (
     LavaTest,
     RetryAction,
 )
 
 
-def handle_testcase(params):
-
-    # FIXME: move to utils
-    data = {}
-    for param in params:
-        parts = param.split('=')
-        if len(parts) == 2:
-            key, value = parts
-            key = key.lower()
-            data[key] = value
-        else:
-            raise JobError(
-                "Ignoring malformed parameter for signal: \"%s\". " % param)
-    return data
-
-
 class TestAction(Action):
     """
     Base class for all actions which run lava test
@@ -58,3 +40,4 @@ class TestAction(Action):
     """
 
     name = 'test'
+    timeout_exception = LAVATimeoutError
