@@ -19,7 +19,6 @@
 # with this program; if not, see <http://www.gnu.org/licenses>.
 
 import re
-import sys
 import time
 import yaml
 import decimal
@@ -33,26 +32,35 @@ from lava_common.exceptions import (
     TestError,
     LAVABug,
 )
-from lava_dispatcher.actions.test import (
-    TestAction,
-    handle_testcase
-)
+from lava_dispatcher.actions.test import TestAction
 from lava_dispatcher.action import Pipeline
 from lava_dispatcher.logical import (
     LavaTest,
     RetryAction
 )
 from lava_dispatcher.connection import SignalMatch
-from lava_dispatcher.protocols.lxc import LxcProtocol
 from lava_common.constants import (
     DEFAULT_V1_PATTERN,
     DEFAULT_V1_FIXUP,
 )
-from functools import reduce
 
 # pylint: disable=too-many-branches,too-many-statements,too-many-instance-attributes,logging-not-lazy
 
 
+def handle_testcase(params):
+    data = {}
+    for param in params:
+        parts = param.split('=')
+        if len(parts) == 2:
+            key, value = parts
+            key = key.lower()
+            data[key] = value
+        else:
+            raise JobError(
+                "Ignoring malformed parameter for signal: \"%s\". " % param)
+    return data
+
+
 class TestShell(LavaTest):
     """
     LavaTestShell Strategy object
@@ -72,6 +80,7 @@ class TestShell(LavaTest):
 
     @classmethod
     def needs_deployment_data(cls):
+        """ Some, not all, deployments will want deployment_data """
         return True
 
     @classmethod
@@ -83,6 +92,7 @@ class TestShell(LavaTest):
         return True
 
 
+@nottest
 class TestShellRetry(RetryAction):
 
     name = "lava-test-retry"
@@ -95,7 +105,7 @@ class TestShellRetry(RetryAction):
 
 
 # FIXME: move to utils and call inside the overlay
-class PatternFixup(object):
+class PatternFixup:
 
     def __init__(self, testdef, count):
         """
@@ -108,7 +118,7 @@ class PatternFixup(object):
         self.fixup = DEFAULT_V1_FIXUP
         if isinstance(testdef, dict) and 'metadata' in testdef:
             self.testdef = testdef
-            self.name = "%d_%s" % (count, reduce(dict.get, ['metadata', 'name'], testdef))
+            self.name = "%d_%s" % (count, testdef["metadata"].get("name"))
         else:
             self.testdef = {}
             self.name = None
@@ -142,6 +152,7 @@ class PatternFixup(object):
         return self.pat
 
 
+@nottest
 class TestShellAction(TestAction):
     """
     Sets up and runs the LAVA Test Shell Definition scripts.
@@ -170,8 +181,8 @@ class TestShellAction(TestAction):
     def _reset_patterns(self):
         # Extend the list of patterns when creating subclasses.
         self.patterns = {
-            "exit": "<LAVA_TEST_RUNNER>: exiting",
-            "error": "<LAVA_TEST_RUNNER>: ([^ ]+) installer failed, skipping",
+            "exit": "<LAVA_TEST_RUNNER EXIT>",
+            "error": "<LAVA_TEST_RUNNER INSTALL_FAIL>",
             "eof": pexpect.EOF,
             "timeout": pexpect.TIMEOUT,
             "signal": r"<LAVA_SIGNAL_(\S+) ([^>]+)>",
@@ -187,15 +198,20 @@ class TestShellAction(TestAction):
         self._reset_patterns()
         super().validate()
 
-    def run(self, connection, max_end_time, args=None):  # pylint: disable=too-many-locals
+    def run(self, connection, max_end_time):  # pylint: disable=too-many-locals
         """
         Common run function for subclasses which define custom patterns
         """
-        super().run(connection, max_end_time, args)
+        super().run(connection, max_end_time)
 
         # Get the connection, specific to this namespace
-        connection_namespace = self.parameters.get('connection-namespace', None)
+        connection_namespace = self.parameters.get('connection-namespace')
         parameters = None
+        if self.timeout.can_skip(self.parameters):
+            self.logger.info(
+                "The timeout has 'skip' enabled. "
+                "If this test action block times out, the job will continue at the next action block.")
+
         if connection_namespace:
             self.logger.debug("Using connection namespace: %s", connection_namespace)
             parameters = {"namespace": connection_namespace}
@@ -234,7 +250,10 @@ class TestShellAction(TestAction):
             action='test', label='results', key='lava_test_results_dir')
         lava_test_sh_cmd = self.get_namespace_data(action='test', label='shared', key='lava_test_sh_cmd')
 
-        if pre_command_list and running == 0:
+        # Any errors arising from this command are not checked.
+        # If the result of the command means that lava-test-runner cannot be found,
+        # this will cause the job to time out as Incomplete.
+        if pre_command_list:
             for command in pre_command_list:
                 connection.sendline(command, delay=self.character_delay)
 
@@ -243,7 +262,6 @@ class TestShellAction(TestAction):
                            "otherwise this is a bug which should be reported.")
 
         self.logger.debug("Using %s" % lava_test_results_dir)
-        connection.sendline('ls -l %s/' % lava_test_results_dir, delay=self.character_delay)
         if lava_test_sh_cmd:
             connection.sendline('export SHELL=%s' % lava_test_sh_cmd, delay=self.character_delay)
 
@@ -376,7 +394,7 @@ class TestShellAction(TestAction):
         revision = self.get_namespace_data(action='test', label=uuid, key='revision')
         res['revision'] = revision if revision else 'unspecified'
         res['namespace'] = self.parameters['namespace']
-        connection_namespace = self.parameters.get('connection_namespace', None)
+        connection_namespace = self.parameters.get('connection_namespace')
         if connection_namespace:
             res['connection-namespace'] = connection_namespace
         commit_id = self.get_namespace_data(action='test', label=uuid, key='commit-id')
@@ -502,6 +520,9 @@ class TestShellAction(TestAction):
         if res:
             # disallow whitespace in test_case_id
             test_case_id = "%s" % res['test_case_id'].replace('/', '_')
+            self.logger.marker(
+                {"case": res["test_case_id"],
+                 "type": "test_case"})
             if ' ' in test_case_id.strip():
                 self.logger.debug("Skipping invalid test_case_id '%s'", test_case_id.strip())
                 return True
@@ -555,7 +576,16 @@ class TestShellAction(TestAction):
                 self.signal_start_run(params)
             elif name == "ENDRUN":
                 self.signal_end_run(params)
+            elif name == "STARTTC":
+                self.logger.marker({"case": params[0],
+                                    "type": "start_test_case"})
+            elif name == "ENDTC":
+                self.logger.marker({"case": params[0],
+                                    "type": "end_test_case"})
             elif name == "TESTCASE":
+                self.logger.marker(
+                    {"case": params[0].replace('TEST_CASE_ID=', ''),
+                     "type": "test_case"})
                 self.signal_test_case(params)
             elif name == "TESTFEEDBACK":
                 self.signal_test_feedback(params)
@@ -567,6 +597,8 @@ class TestShellAction(TestAction):
                     name = ret
             elif name == "TESTRAISE":
                 raise TestError(' '.join(params))
+            elif name == "TESTEVENT":
+                self.logger.event(' '.join(params))
 
             self.signal_director.signal(name, params)
             ret_val = True
@@ -583,7 +615,7 @@ class TestShellAction(TestAction):
         retval = test_connection.expect(list(self.patterns.values()), timeout=timeout)
         return self.check_patterns(list(self.patterns.keys())[retval], test_connection, check_char)
 
-    class SignalDirector(object):
+    class SignalDirector:
 
         # FIXME: create proxy handlers
         def __init__(self, protocol=None):
