@@ -118,7 +118,7 @@ class MultinodeProtocol(Protocol):  # pylint: disable=too-many-instance-attribut
         try:
             self.sock.connect((self.settings['coordinator_hostname'], self.settings['port']))
             return True
-        except socket.error as exc:
+        except OSError as exc:
             self.logger.exception("socket error on connect: %d %s %s",
                                   exc.errno,
                                   self.settings['coordinator_hostname'],
@@ -139,7 +139,7 @@ class MultinodeProtocol(Protocol):  # pylint: disable=too-many-instance-attribut
             if ret_bytes == 0:
                 self.logger.debug("zero bytes sent for message - connection closed?")
                 return False
-        except socket.error as exc:
+        except OSError as exc:
             self.logger.exception("socket error '%s' on send", exc.message)
             self.sock.close()
             return False
@@ -157,7 +157,7 @@ class MultinodeProtocol(Protocol):  # pylint: disable=too-many-instance-attribut
             while recv_count < msg_count:
                 response += self.sock.recv(self.blocks).decode("utf-8")
                 recv_count += self.blocks
-        except socket.error as exc:
+        except OSError as exc:
             self.logger.exception("socket error '%d' on response", exc.errno)
             self.sock.close()
             return json.dumps({"response": "wait"})
@@ -403,7 +403,7 @@ class MultinodeProtocol(Protocol):  # pylint: disable=too-many-instance-attribut
         try:
             return self._api_select(json.dumps(args[0]))
         except (ValueError, TypeError) as exc:
-            msg = re.sub('\s+', ' ', ''.join(traceback.format_exc().split('\n')))
+            msg = re.sub(r'\s+', ' ', ''.join(traceback.format_exc().split('\n')))
             logger = logging.getLogger("dispatcher")
             logger.exception(msg)
             raise JobError("Invalid call to %s %s" % (self.name, exc))
