@@ -34,9 +34,11 @@ class DepthchargeFactory:
     Factory objects are dispatcher based classes, independent
     of any database objects.
     """
+
     def create_jaq_job(self, filename):  # pylint: disable=no-self-use
-        device = NewDevice(os.path.join(
-            os.path.dirname(__file__), '../devices/jaq-01.yaml'))
+        device = NewDevice(
+            os.path.join(os.path.dirname(__file__), "../devices/jaq-01.yaml")
+        )
         yaml = os.path.join(os.path.dirname(__file__), filename)
         with open(yaml) as sample_job_data:
             parser = JobParser()
@@ -46,46 +48,55 @@ class DepthchargeFactory:
 
 
 class TestDepthchargeAction(StdoutTestCase):
-
     def setUp(self):
         super().setUp()
         self.factory = DepthchargeFactory()
 
-    @unittest.skipIf(infrastructure_error('mkimage'), "mkimage not installed")
+    @unittest.skipIf(infrastructure_error("mkimage"), "mkimage not installed")
     def test_depthcharge(self):
-        job = self.factory.create_jaq_job('sample_jobs/depthcharge.yaml')
+        job = self.factory.create_jaq_job("sample_jobs/depthcharge.yaml")
         self.assertIsNotNone(job)
 
-        description_ref = self.pipeline_reference('depthcharge.yaml', job=job)
+        description_ref = self.pipeline_reference("depthcharge.yaml", job=job)
         self.assertEqual(description_ref, job.pipeline.describe(False))
 
         self.assertIsNone(job.validate())
 
         self.assertEqual(
             [action.name for action in job.pipeline.actions],
-            ['tftp-deploy', 'depthcharge-action', 'finalize']
+            ["tftp-deploy", "depthcharge-action", "finalize"],
         )
 
-        tftp = [action for action in job.pipeline.actions
-                if action.name == 'tftp-deploy'][0]
-        prep_overlay = [action for action in tftp.pipeline.actions
-                        if action.name == 'prepare-tftp-overlay'][0]
-        prep_kernel = [action for action in prep_overlay.pipeline.actions
-                       if action.name == 'prepare-kernel'][0]
+        tftp = [
+            action for action in job.pipeline.actions if action.name == "tftp-deploy"
+        ][0]
+        prep_overlay = [
+            action
+            for action in tftp.pipeline.actions
+            if action.name == "prepare-tftp-overlay"
+        ][0]
+        prep_kernel = [
+            action
+            for action in prep_overlay.pipeline.actions
+            if action.name == "prepare-kernel"
+        ][0]
         self.assertEqual(
             [action.name for action in prep_kernel.internal_pipeline.actions],
-            ['prepare-fit']
+            ["prepare-fit"],
         )
 
-        prep_fit = [action for action in prep_kernel.pipeline.actions
-                    if action.name == 'prepare-fit'][0]
+        prep_fit = [
+            action
+            for action in prep_kernel.pipeline.actions
+            if action.name == "prepare-fit"
+        ][0]
         params = {
-            'arch': 'neo-gothic',
-            'load_addr': '0x1234',
-            'kernel': '/some/zImage',
-            'dtb': '/some/file.dtb',
-            'ramdisk': '/some/ramdisk.cpio',
-            'fit_path': '/does/not/exist',
+            "arch": "neo-gothic",
+            "load_addr": "0x1234",
+            "kernel": "/some/zImage",
+            "dtb": "/some/file.dtb",
+            "ramdisk": "/some/ramdisk.cpio",
+            "fit_path": "/does/not/exist",
         }
         cmd_ref = 'mkimage \
 -D "-I dts -O dtb -p 2048" \
@@ -98,20 +109,28 @@ class TestDepthchargeAction(StdoutTestCase):
 -a {load_addr} \
 -b {dtb} \
 -i {ramdisk} \
-{fit_path}'.format(**params)
+{fit_path}'.format(
+            **params
+        )
         cmd = prep_fit._make_mkimage_command(params)  # pylint: disable=protected-access
-        self.assertEqual(cmd_ref, ' '.join(cmd))
+        self.assertEqual(cmd_ref, " ".join(cmd))
 
-        depthcharge = [action for action in job.pipeline.actions
-                       if action.name == 'depthcharge-action'][0]
+        depthcharge = [
+            action
+            for action in job.pipeline.actions
+            if action.name == "depthcharge-action"
+        ][0]
         self.assertEqual(
             [action.name for action in depthcharge.internal_pipeline.actions],
-            ['depthcharge-overlay', 'connect-device', 'depthcharge-retry']
+            ["depthcharge-overlay", "connect-device", "depthcharge-retry"],
         )
 
-        retry = [action for action in depthcharge.internal_pipeline.actions
-                 if action.name == 'depthcharge-retry'][0]
+        retry = [
+            action
+            for action in depthcharge.internal_pipeline.actions
+            if action.name == "depthcharge-retry"
+        ][0]
         self.assertEqual(
             [action.name for action in retry.internal_pipeline.actions],
-            ['reset-device', 'depthcharge-start', 'bootloader-commands']
+            ["reset-device", "depthcharge-start", "bootloader-commands"],
         )
