@@ -22,8 +22,9 @@ import os
 import time
 import pexpect
 from lava_common.constants import (
-    KERNEL_FREE_UNUSED_MSG, KERNEL_PANIC_MSG,
-    KERNEL_FREE_INIT_MSG
+    KERNEL_FREE_UNUSED_MSG,
+    KERNEL_PANIC_MSG,
+    KERNEL_FREE_INIT_MSG,
 )
 from lava_common.exceptions import JobError
 from lava_dispatcher.utils.messages import LinuxKernelMessages
@@ -31,7 +32,6 @@ from lava_dispatcher.test.test_basic import StdoutTestCase
 
 
 class Kernel:  # pylint: disable=too-few-public-methods
-
     def __init__(self):
         super().__init__()
         self.existing_prompt = None
@@ -48,7 +48,6 @@ class Kernel:  # pylint: disable=too-few-public-methods
 
 
 class Child(Kernel):  # pylint: disable=too-few-public-methods
-
     def run(self, prompt_list):
         if KERNEL_FREE_INIT_MSG in prompt_list:
             index = prompt_list.index(KERNEL_FREE_INIT_MSG)
@@ -63,17 +62,16 @@ class Child(Kernel):  # pylint: disable=too-few-public-methods
 
 
 class FakeConnection:  # pylint: disable=too-few-public-methods
-
     def __init__(self, child, prompt_str):
         super().__init__()
         self.raw_connection = child
         self.prompt_str = prompt_str
-        self.check_char = '#'
+        self.check_char = "#"
         self.faketimeout = 30
         self.connected = True
         self.name = "fake-connection"
 
-    def sendline(self, s='', delay=0):  # pylint: disable=invalid-name
+    def sendline(self, s="", delay=0):  # pylint: disable=invalid-name
         pass
 
     def force_prompt_wait(self, remaining=None):  # pylint: disable=unused-argument
@@ -89,14 +87,13 @@ class FakeConnection:  # pylint: disable=too-few-public-methods
 
 
 class TestBootMessages(StdoutTestCase):  # pylint: disable=too-many-public-methods
-
     def setUp(self):
         super().setUp()
         self.max_end_time = time.time() + 30
 
     def test_existing_prompt(self):
         kernel = Kernel()
-        prompt_list = kernel.run(['root@debian:'])
+        prompt_list = kernel.run(["root@debian:"])
         self.assertIn(KERNEL_FREE_INIT_MSG, prompt_list)
         child = Child()
         prompt_list = child.run(prompt_list)
@@ -107,9 +104,9 @@ class TestBootMessages(StdoutTestCase):  # pylint: disable=too-many-public-metho
         The same logfile passes kernel boot and fails
         to find init - so the panic needs to be caught by InitMessages
         """
-        logfile = os.path.join(os.path.dirname(__file__), 'kernel-panic.txt')
+        logfile = os.path.join(os.path.dirname(__file__), "kernel-panic.txt")
         self.assertTrue(os.path.exists(logfile))
-        child = pexpect.spawn('cat', [logfile])
+        child = pexpect.spawn("cat", [logfile])
         message_list = LinuxKernelMessages.get_kernel_prompts()
         self.assertIsNotNone(message_list)
         self.assertIn(LinuxKernelMessages.MESSAGE_CHOICES[0][1], message_list)
@@ -120,24 +117,29 @@ class TestBootMessages(StdoutTestCase):  # pylint: disable=too-many-public-metho
         self.assertIn(LinuxKernelMessages.MESSAGE_CHOICES[5][1], message_list)
         connection = FakeConnection(child, message_list)
         with self.assertRaises(JobError):
-            result = LinuxKernelMessages.parse_failures(connection, max_end_time=self.max_end_time)
+            result = LinuxKernelMessages.parse_failures(
+                connection, max_end_time=self.max_end_time
+            )
 
     def test_kernel_1(self):
-        logfile = os.path.join(os.path.dirname(__file__), 'kernel-1.txt')
+        logfile = os.path.join(os.path.dirname(__file__), "kernel-1.txt")
         self.assertTrue(os.path.exists(logfile))
-        child = pexpect.spawn('cat', [logfile])
+        child = pexpect.spawn("cat", [logfile])
         message_list = LinuxKernelMessages.get_kernel_prompts()
         connection = FakeConnection(child, message_list)
-        results = LinuxKernelMessages.parse_failures(connection, max_end_time=self.max_end_time)
+        results = LinuxKernelMessages.parse_failures(
+            connection, max_end_time=self.max_end_time
+        )
         self.assertEqual(len(results), 1)
-        self.assertEqual(results[0],
-                         {'message': 'kernel-messages',
-                          'success': 'Freeing unused kernel memory'})
+        self.assertEqual(
+            results[0],
+            {"message": "kernel-messages", "success": "Freeing unused kernel memory"},
+        )
 
     def test_kernel_2(self):
-        logfile = os.path.join(os.path.dirname(__file__), 'kernel-2.txt')
+        logfile = os.path.join(os.path.dirname(__file__), "kernel-2.txt")
         self.assertTrue(os.path.exists(logfile))
-        child = pexpect.spawn('cat', [logfile])
+        child = pexpect.spawn("cat", [logfile])
         message_list = LinuxKernelMessages.get_kernel_prompts()
         self.assertIsNotNone(message_list)
         self.assertIn(LinuxKernelMessages.MESSAGE_CHOICES[0][1], message_list)
@@ -147,20 +149,26 @@ class TestBootMessages(StdoutTestCase):  # pylint: disable=too-many-public-metho
         self.assertIn(LinuxKernelMessages.MESSAGE_CHOICES[4][1], message_list)
         self.assertIn(LinuxKernelMessages.MESSAGE_CHOICES[5][1], message_list)
         connection = FakeConnection(child, message_list)
-        results = LinuxKernelMessages.parse_failures(connection, max_end_time=self.max_end_time)
+        results = LinuxKernelMessages.parse_failures(
+            connection, max_end_time=self.max_end_time
+        )
         self.assertEqual(len(list(results)), 14)
         message_list = LinuxKernelMessages.get_init_prompts()
-        child = pexpect.spawn('cat', [logfile])
+        child = pexpect.spawn("cat", [logfile])
         connection = FakeConnection(child, message_list)
-        results = LinuxKernelMessages.parse_failures(connection, max_end_time=self.max_end_time)
+        results = LinuxKernelMessages.parse_failures(
+            connection, max_end_time=self.max_end_time
+        )
         self.assertEqual(len(list(results)), 13)
 
     def test_kernel_4(self):
-        logfile = os.path.join(os.path.dirname(__file__), 'kernel-4.txt')
+        logfile = os.path.join(os.path.dirname(__file__), "kernel-4.txt")
         self.assertTrue(os.path.exists(logfile))
-        child = pexpect.spawn('cat', [logfile])
+        child = pexpect.spawn("cat", [logfile])
         message_list = LinuxKernelMessages.get_init_prompts()
         self.assertIsNotNone(message_list)
         connection = FakeConnection(child, message_list)
         with self.assertRaises(JobError):
-            results = LinuxKernelMessages.parse_failures(connection, max_end_time=self.max_end_time)
+            results = LinuxKernelMessages.parse_failures(
+                connection, max_end_time=self.max_end_time
+            )
