@@ -44,17 +44,23 @@ class FastBootFactory(Factory):  # pylint: disable=too-few-public-methods
         with open(
             os.path.join(
                 os.path.dirname(__file__),
-                '..', '..', 'lava_scheduler_app', 'tests',
-                'devices', 'hi6220-hikey-bl-01.jinja2')) as hikey:
+                "..",
+                "..",
+                "lava_scheduler_app",
+                "tests",
+                "devices",
+                "hi6220-hikey-bl-01.jinja2",
+            )
+        ) as hikey:
             data = hikey.read()
         test_template = self.prepare_jinja_template(hostname, data)
         rendered = test_template.render()
         return (rendered, data)
 
     def create_hikey_bl_job(self, filename):
-        (data, device_dict) = self.create_hikey_bl_device('hi6220-hikey-01')
+        (data, device_dict) = self.create_hikey_bl_device("hi6220-hikey-01")
         device = NewDevice(yaml.safe_load(data))
-        self.validate_data('hi6220-hikey-01', device_dict)
+        self.validate_data("hi6220-hikey-01", device_dict)
         fastboot_yaml = os.path.join(os.path.dirname(__file__), filename)
         with open(fastboot_yaml) as sample_job_data:
             parser = JobParser()
@@ -64,47 +70,69 @@ class FastBootFactory(Factory):  # pylint: disable=too-few-public-methods
 
 
 class TestRecoveryMode(StdoutTestCase):  # pylint: disable=too-many-public-methods
-
     def setUp(self):
         super().setUp()
         self.factory = FastBootFactory()
-        self.job = self.factory.create_hikey_bl_job('sample_jobs/hi6220-recovery.yaml')
+        self.job = self.factory.create_hikey_bl_job("sample_jobs/hi6220-recovery.yaml")
 
-    @unittest.skipIf(infrastructure_error_multi_paths(
-        ['lxc-info', 'img2simg', 'simg2img']),
-        "lxc or img2simg or simg2img not installed")
+    @unittest.skipIf(
+        infrastructure_error_multi_paths(["lxc-info", "img2simg", "simg2img"]),
+        "lxc or img2simg or simg2img not installed",
+    )
     def test_structure(self):
         self.assertIsNotNone(self.job)
         self.job.validate()
 
-        description_ref = self.pipeline_reference('hi6220-recovery.yaml', job=self.job)
+        description_ref = self.pipeline_reference("hi6220-recovery.yaml", job=self.job)
         self.assertEqual(description_ref, self.job.pipeline.describe(False))
 
         requires_board_id = not allow_fs_label(self.job.device)
         self.assertFalse(requires_board_id)
-        if 'device_info' in self.job.device:
-            for usb_device in self.job.device['device_info']:
-                if usb_device.get('board_id', '') in ['', '0000000000'] \
-                        and requires_board_id:
+        if "device_info" in self.job.device:
+            for usb_device in self.job.device["device_info"]:
+                if (
+                    usb_device.get("board_id", "") in ["", "0000000000"]
+                    and requires_board_id
+                ):
                     self.fail("[LXC_CREATE] board_id unset")
 
     def test_commands(self):
-        enter = [action for action in self.job.pipeline.actions if action.name == 'recovery-boot'][0]
-        mode = [action for action in enter.internal_pipeline.actions if action.name == 'switch-recovery'][0]
-        recovery = self.job.device['actions']['deploy']['methods']['recovery']
-        self.assertIsNotNone(recovery['commands'].get(mode.mode))
+        enter = [
+            action
+            for action in self.job.pipeline.actions
+            if action.name == "recovery-boot"
+        ][0]
+        mode = [
+            action
+            for action in enter.internal_pipeline.actions
+            if action.name == "switch-recovery"
+        ][0]
+        recovery = self.job.device["actions"]["deploy"]["methods"]["recovery"]
+        self.assertIsNotNone(recovery["commands"].get(mode.mode))
         self.assertEqual(
             [
-                '/home/neil/lava-lab/shared/lab-scripts/eth008_control -a 10.15.0.171 -r 1 -s off',
-                '/home/neil/lava-lab/shared/lab-scripts/eth008_control -a 10.15.0.171 -r 2 -s on'],
-            recovery['commands'][mode.mode])
-        self.assertEqual('recovery_mode', mode.mode)
-        exit_mode = [action for action in self.job.pipeline.actions if action.name == 'recovery-boot'][1]
-        mode = [action for action in exit_mode.internal_pipeline.actions if action.name == 'switch-recovery'][0]
-        self.assertIsNotNone(recovery['commands'].get(mode.mode))
+                "/home/neil/lava-lab/shared/lab-scripts/eth008_control -a 10.15.0.171 -r 1 -s off",
+                "/home/neil/lava-lab/shared/lab-scripts/eth008_control -a 10.15.0.171 -r 2 -s on",
+            ],
+            recovery["commands"][mode.mode],
+        )
+        self.assertEqual("recovery_mode", mode.mode)
+        exit_mode = [
+            action
+            for action in self.job.pipeline.actions
+            if action.name == "recovery-boot"
+        ][1]
+        mode = [
+            action
+            for action in exit_mode.internal_pipeline.actions
+            if action.name == "switch-recovery"
+        ][0]
+        self.assertIsNotNone(recovery["commands"].get(mode.mode))
         self.assertEqual(
             [
-                '/home/neil/lava-lab/shared/lab-scripts/eth008_control -a 10.15.0.171 -r 1 -s on',
-                '/home/neil/lava-lab/shared/lab-scripts/eth008_control -a 10.15.0.171 -r 2 -s off'],
-            recovery['commands'][mode.mode])
-        self.assertEqual('recovery_exit', mode.mode)
+                "/home/neil/lava-lab/shared/lab-scripts/eth008_control -a 10.15.0.171 -r 1 -s on",
+                "/home/neil/lava-lab/shared/lab-scripts/eth008_control -a 10.15.0.171 -r 2 -s off",
+            ],
+            recovery["commands"][mode.mode],
+        )
+        self.assertEqual("recovery_exit", mode.mode)
