@@ -1,26 +1,26 @@
-# Copyright (C) 2015 Linaro Limited
+# -*- coding: utf-8 -*-
+# Copyright (C) 2015-2018 Linaro Limited
 #
 # Author: Stevan Radakovic <stevan.radakovic@linaro.org>
 #
-# This file is part of Lava Server.
+# This file is part of LAVA.
 #
-# Lava Server is free software: you can redistribute it and/or modify
+# LAVA is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License version 3
 # as published by the Free Software Foundation
 #
-# Lava Server is distributed in the hope that it will be useful,
+# LAVA is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
-# along with Lava Server.  If not, see <http://www.gnu.org/licenses/>.
+# along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
 import csv
 import os
 import shutil
 import simplejson
-import sys
 import tempfile
 
 from django.db import IntegrityError
@@ -86,9 +86,6 @@ from django_tables2 import (
 
 from lava.utils.lavatable import LavaView
 
-if sys.version_info[0] == 3:
-    basestring = str
-
 
 class QueryViewDoesNotExistError(Exception):
     """ Raise when corresponding query materialized view does not exist. """
@@ -119,7 +116,7 @@ class OtherQueryView(LavaView):
 class GroupQueryView(LavaView):
 
     def __init__(self, request, group, **kwargs):
-        super(GroupQueryView, self).__init__(request, **kwargs)
+        super().__init__(request, **kwargs)
         self.query_group = group
 
     def get_queryset(self):
@@ -147,7 +144,7 @@ class QueryCustomResultView(LavaView):
         self.content_type = content_type
         self.conditions = conditions
         self.request = request
-        super(QueryCustomResultView, self).__init__(request, **kwargs)
+        super().__init__(request, **kwargs)
 
     def get_queryset(self):
         return Query.get_queryset(
@@ -161,7 +158,7 @@ class QueryResultView(LavaView):
     def __init__(self, query, request, **kwargs):
         self.query = query
         self.request = request
-        super(QueryResultView, self).__init__(request, **kwargs)
+        super().__init__(request, **kwargs)
 
     def get_queryset(self):
         return self.query.get_results(self.request.user)
@@ -528,7 +525,7 @@ def query_add_group(request, username, name):
         if not old_group.query_set.count():
             old_group.delete()
 
-    return HttpResponse(group_name, content_type='application/json')
+    return HttpResponseRedirect(query.get_absolute_url() + "/+detail")
 
 
 @login_required
@@ -544,12 +541,15 @@ def query_select_group(request, username, name):
     if not group_name:
         query.group = None
     else:
-        group = Group.objects.get(name=group_name)
+        try:
+            group = Group.objects.get(name=group_name)
+        except Group.DoesNotExist:
+            group = None
         query.group = group
 
     query.save()
 
-    return HttpResponse(group_name, content_type='application/json')
+    return HttpResponseRedirect(query.get_absolute_url() + "/+detail")
 
 
 @login_required
@@ -733,8 +733,8 @@ def _export_query(query_results, content_type, filename):
     removed_fields = [
         # TestJob fields:
         "user_id", "actual_device_id", "definition", "admin_notifications",
-        "group_id", "id", "original_definition", "health_check",
-        "sub_id", "submitter_id", "testdata", "testsuite",
+        "group_id", "multinode_definition", "original_definition", "health_check",
+        "sub_id", "submitter_id", "testdata", "testsuite", "target_group",
         "notification", "testjobmaterializedview", "testjobuser",
         "pipeline_compatibility",
         # TestSuite fields:
@@ -755,7 +755,7 @@ def _export_query(query_results, content_type, filename):
         for result in query_results:
             result_dict = result.__dict__.copy()
             # Encode the strings if necessary.
-            out.writerow({k: (v.encode('utf8') if isinstance(v, basestring) else v) for k, v in result_dict.items()})
+            out.writerow({k: (v.encode('utf8') if isinstance(v, str) else v) for k, v in result_dict.items()})
 
     response = HttpResponse(content_type='text/csv')
     response['Content-Disposition'] = "attachment; filename=%s.csv" % filename
