@@ -26,9 +26,20 @@ from django.db import transaction
 from django.conf import settings
 
 from lava_scheduler_app.models import (
-    Architecture, Alias, BitWidth, Core, DefaultDeviceOwner, Device,
-    DeviceType, JobFailureTag, NotificationRecipient, ProcessorFamily, Tag,
-    TestJob, User, Worker
+    Architecture,
+    Alias,
+    BitWidth,
+    Core,
+    DefaultDeviceOwner,
+    Device,
+    DeviceType,
+    JobFailureTag,
+    NotificationRecipient,
+    ProcessorFamily,
+    Tag,
+    TestJob,
+    User,
+    Worker,
 )
 from linaro_django_xmlrpc.models import AuthToken
 
@@ -39,28 +50,28 @@ from linaro_django_xmlrpc.models import AuthToken
 class AliasAdmin(admin.ModelAdmin):
     def get_readonly_fields(self, _, obj=None):
         if obj:  # editing an existing object
-            return self.readonly_fields + ('name',)
+            return self.readonly_fields + ("name",)
         return self.readonly_fields
 
 
 class ArchitectureAdmin(admin.ModelAdmin):
     def get_readonly_fields(self, _, obj=None):
         if obj:  # editing an existing object
-            return self.readonly_fields + ('name',)
+            return self.readonly_fields + ("name",)
         return self.readonly_fields
 
 
 class BitWidthAdmin(admin.ModelAdmin):
     def get_readonly_fields(self, _, obj=None):
         if obj:  # editing an existing object
-            return self.readonly_fields + ('width',)
+            return self.readonly_fields + ("width",)
         return self.readonly_fields
 
 
 class CoreAdmin(admin.ModelAdmin):
     def get_readonly_fields(self, _, obj=None):
         if obj:  # editing an existing object
-            return self.readonly_fields + ('name',)
+            return self.readonly_fields + ("name",)
         return self.readonly_fields
 
 
@@ -69,11 +80,14 @@ class DefaultOwnerInline(admin.StackedInline):
     Exposes the default owner override class
     in the Django admin interface
     """
+
     model = DefaultDeviceOwner
     can_delete = False
 
 
-def expire_user_action(modeladmin, request, queryset):  # pylint: disable=unused-argument
+def expire_user_action(
+    modeladmin, request, queryset
+):  # pylint: disable=unused-argument
     for user in queryset.filter(is_active=True):
         AuthToken.objects.filter(user=user).delete()
         user.is_staff = False
@@ -86,14 +100,15 @@ def expire_user_action(modeladmin, request, queryset):  # pylint: disable=unused
         user.save()
 
 
-expire_user_action.short_description = 'Expire user account'
+expire_user_action.short_description = "Expire user account"
 
 
 class UserAdmin(UserAdmin):
     """
     Defines the override class for DefaultOwnerInline
     """
-    inlines = (DefaultOwnerInline, )
+
+    inlines = (DefaultOwnerInline,)
     actions = [expire_user_action]
 
     def has_delete_permission(self, request, obj=None):
@@ -118,92 +133,89 @@ def cancel_action(modeladmin, request, queryset):  # pylint: disable=unused-argu
                     testjob.save()
 
 
-cancel_action.short_description = 'cancel selected jobs'
+cancel_action.short_description = "cancel selected jobs"
 
 
 def fail_action(modeladmin, request, queryset):
     if request.user.is_superuser:
         with transaction.atomic():
-            for testjob in queryset.select_for_update().filter(state=TestJob.STATE_CANCELING):
+            for testjob in queryset.select_for_update().filter(
+                state=TestJob.STATE_CANCELING
+            ):
                 testjob.go_state_finished(TestJob.HEALTH_INCOMPLETE)
                 testjob.save()
 
 
-fail_action.short_description = 'fail selected jobs'
+fail_action.short_description = "fail selected jobs"
 
 
 class ActiveDevicesFilter(admin.SimpleListFilter):
-    title = 'Active devices'
-    parameter_name = 'state'
+    title = "Active devices"
+    parameter_name = "state"
 
     def lookups(self, request, model_admin):
-        return (
-            ('NoRetired', 'Exclude retired'),
-            ('CurrentJob', 'With a current Job')
-        )
+        return (("NoRetired", "Exclude retired"), ("CurrentJob", "With a current Job"))
 
     def queryset(self, request, queryset):
-        if self.value() == 'NoRetired':
-            return queryset.exclude(health=Device.HEALTH_RETIRED).order_by('hostname')
-        if self.value() == 'CurrentJob':
-            return queryset.filter(state__in=[Device.STATE_RESERVED, Device.STATE_RUNNING]).order_by('hostname')
+        if self.value() == "NoRetired":
+            return queryset.exclude(health=Device.HEALTH_RETIRED).order_by("hostname")
+        if self.value() == "CurrentJob":
+            return queryset.filter(
+                state__in=[Device.STATE_RESERVED, Device.STATE_RUNNING]
+            ).order_by("hostname")
 
 
 class ActualDeviceFilter(admin.SimpleListFilter):
-    title = 'Actual Device (except retired)'
-    parameter_name = 'actual_device'
+    title = "Actual Device (except retired)"
+    parameter_name = "actual_device"
 
     def lookups(self, request, model_admin):
         list_of_types = []
-        queryset = Device.objects.exclude(health=Device.HEALTH_RETIRED).order_by('hostname')
+        queryset = Device.objects.exclude(health=Device.HEALTH_RETIRED).order_by(
+            "hostname"
+        )
         for dev_type in queryset:
-            list_of_types.append(
-                (str(dev_type.hostname), dev_type.hostname)
-            )
+            list_of_types.append((str(dev_type.hostname), dev_type.hostname))
         return sorted(list_of_types, key=lambda tp: tp[1])
 
     def queryset(self, request, queryset):
         if self.value():
             return queryset.filter(actual_device__hostname=self.value())
-        return queryset.order_by('actual_device__hostname')
+        return queryset.order_by("actual_device__hostname")
 
 
 class DeviceTypeFilter(admin.SimpleListFilter):
-    title = 'Device Type'
-    parameter_name = 'device_type'
+    title = "Device Type"
+    parameter_name = "device_type"
 
     def lookups(self, request, model_admin):
         list_of_types = []
         queryset = DeviceType.objects.all()
         for dev_type in queryset:
-            list_of_types.append(
-                (str(dev_type.name), dev_type.name)
-            )
+            list_of_types.append((str(dev_type.name), dev_type.name))
         return sorted(list_of_types, key=lambda tp: tp[1])
 
     def queryset(self, request, queryset):
         if self.value():
             return queryset.filter(device_type__name=self.value())
-        return queryset.order_by('device_type__name')
+        return queryset.order_by("device_type__name")
 
 
 class RequestedDeviceTypeFilter(admin.SimpleListFilter):
-    title = 'Requested Device Type'
-    parameter_name = 'requested_device_type'
+    title = "Requested Device Type"
+    parameter_name = "requested_device_type"
 
     def lookups(self, request, model_admin):
         list_of_types = []
-        queryset = DeviceType.objects.order_by('name')
+        queryset = DeviceType.objects.order_by("name")
         for dev_type in queryset:
-            list_of_types.append(
-                (str(dev_type.name), dev_type.name)
-            )
+            list_of_types.append((str(dev_type.name), dev_type.name))
         return sorted(list_of_types, key=lambda tp: tp[1])
 
     def queryset(self, request, queryset):
         if self.value():
             return queryset.filter(requested_device_type__name=self.value())
-        return queryset.order_by('requested_device_type__name')
+        return queryset.order_by("requested_device_type__name")
 
 
 def _update_devices_health(request, queryset, health):
@@ -212,7 +224,10 @@ def _update_devices_health(request, queryset, health):
             old_health_display = device.get_health_display()
             device.health = health
             device.save()
-            device.log_admin_entry(request.user, "%s → %s" % (old_health_display, device.get_health_display()))
+            device.log_admin_entry(
+                request.user,
+                "%s → %s" % (old_health_display, device.get_health_display()),
+            )
 
 
 def device_health_good(modeladmin, request, queryset):
@@ -233,32 +248,42 @@ def device_health_retired(modeladmin, request, queryset):
 
 device_health_good.short_description = "Update health of selected devices to Good"
 device_health_unknown.short_description = "Update health of selected devices to Unknown"
-device_health_maintenance.short_description = "Update health of selected devices to Maintenance"
+device_health_maintenance.short_description = (
+    "Update health of selected devices to Maintenance"
+)
 device_health_retired.short_description = "Update health of selected devices to Retired"
 
 
 class DeviceAdmin(admin.ModelAdmin):
-    list_filter = (DeviceTypeFilter, 'state', ActiveDevicesFilter,
-                   'health', 'worker_host')
-    raw_id_fields = ['last_health_report_job']
+    list_filter = (
+        DeviceTypeFilter,
+        "state",
+        ActiveDevicesFilter,
+        "health",
+        "worker_host",
+    )
+    raw_id_fields = ["last_health_report_job"]
 
     def has_health_check(self, obj):
         return bool(obj.get_health_check())
+
     has_health_check.boolean = True
     has_health_check.short_description = "HC"
 
     def health_check_enabled(self, obj):
         return not obj.device_type.disable_health_check
+
     health_check_enabled.boolean = True
     health_check_enabled.short_description = "HC enabled"
 
     def get_readonly_fields(self, _, obj=None):
         if obj:  # editing an existing object
-            return self.readonly_fields + ('hostname',)
+            return self.readonly_fields + ("hostname",)
         return self.readonly_fields
 
     def valid_device(self, obj):
         return bool(obj.is_valid())
+
     valid_device.boolean = True
     valid_device.short_description = "Config"
 
@@ -269,46 +294,82 @@ class DeviceAdmin(admin.ModelAdmin):
         return settings.ALLOW_ADMIN_DELETE
 
     fieldsets = (
-        ('Properties', {
-            'fields': ('hostname', 'device_type', 'worker_host', 'device_version')}),
-        ('Device owner', {
-            'fields': (('user', 'group'), ('physical_owner', 'physical_group'), 'is_public')}),
-        ('Status', {
-            'fields': (('state', 'health'), ('last_health_report_job', 'current_job'))}),
-        ('Advanced properties', {
-            'fields': ('description', 'tags', ('device_dictionary_jinja')),
-            'classes': ('collapse', )
-        }),
+        (
+            "Properties",
+            {"fields": ("hostname", "device_type", "worker_host", "device_version")},
+        ),
+        (
+            "Device owner",
+            {
+                "fields": (
+                    ("user", "group"),
+                    ("physical_owner", "physical_group"),
+                    "is_public",
+                )
+            },
+        ),
+        (
+            "Status",
+            {
+                "fields": (
+                    ("state", "health"),
+                    ("last_health_report_job", "current_job"),
+                )
+            },
+        ),
+        (
+            "Advanced properties",
+            {
+                "fields": ("description", "tags", ("device_dictionary_jinja")),
+                "classes": ("collapse",),
+            },
+        ),
     )
-    readonly_fields = ('device_dictionary_jinja', 'state', 'current_job')
-    list_display = ('hostname', 'device_type', 'current_job', 'worker_host',
-                    'state', 'health', 'has_health_check',
-                    'health_check_enabled', 'is_public',
-                    'valid_device')
-    search_fields = ('hostname', 'device_type__name')
-    ordering = ['hostname']
-    actions = [device_health_good, device_health_unknown,
-               device_health_maintenance, device_health_retired]
+    readonly_fields = ("device_dictionary_jinja", "state", "current_job")
+    list_display = (
+        "hostname",
+        "device_type",
+        "current_job",
+        "worker_host",
+        "state",
+        "health",
+        "has_health_check",
+        "health_check_enabled",
+        "is_public",
+        "valid_device",
+    )
+    search_fields = ("hostname", "device_type__name")
+    ordering = ["hostname"]
+    actions = [
+        device_health_good,
+        device_health_unknown,
+        device_health_maintenance,
+        device_health_retired,
+    ]
 
 
 class VisibilityForm(forms.ModelForm):
-
     def clean_viewing_groups(self):
-        viewing_groups = self.cleaned_data['viewing_groups']
-        visibility = self.cleaned_data['visibility']
+        viewing_groups = self.cleaned_data["viewing_groups"]
+        visibility = self.cleaned_data["visibility"]
         if len(viewing_groups) != 1 and visibility == TestJob.VISIBLE_GROUP:
-            raise ValidationError("Group visibility must have exactly one viewing group.")
+            raise ValidationError(
+                "Group visibility must have exactly one viewing group."
+            )
         elif len(viewing_groups) != 0 and visibility == TestJob.VISIBLE_PERSONAL:
-            raise ValidationError("Personal visibility cannot have any viewing groups assigned.")
+            raise ValidationError(
+                "Personal visibility cannot have any viewing groups assigned."
+            )
         elif len(viewing_groups) != 0 and visibility == TestJob.VISIBLE_PUBLIC:
-            raise ValidationError("Pulibc visibility cannot have any viewing groups assigned.")
-        return self.cleaned_data['viewing_groups']
+            raise ValidationError(
+                "Pulibc visibility cannot have any viewing groups assigned."
+            )
+        return self.cleaned_data["viewing_groups"]
 
 
 class TestJobAdmin(admin.ModelAdmin):
-
     def requested_device_type_name(self, obj):
-        return '' if obj.requested_device_type is None else obj.requested_device_type
+        return "" if obj.requested_device_type is None else obj.requested_device_type
 
     def has_add_permission(self, request):
         return False
@@ -316,29 +377,51 @@ class TestJobAdmin(admin.ModelAdmin):
     def has_delete_permission(self, request, obj=None):
         return settings.ALLOW_ADMIN_DELETE
 
-    requested_device_type_name.short_description = 'Request device type'
+    requested_device_type_name.short_description = "Request device type"
     form = VisibilityForm
     actions = [cancel_action, fail_action]
-    list_filter = ('state', RequestedDeviceTypeFilter, ActualDeviceFilter)
+    list_filter = ("state", RequestedDeviceTypeFilter, ActualDeviceFilter)
     fieldsets = (
-        ('Owner', {
-            'fields': ('user', 'group', 'submitter', 'is_public', 'visibility', 'viewing_groups')}),
-        ('Request', {
-            'fields': ('requested_device_type', 'priority', 'health_check')}),
-        ('Advanced properties', {
-            'fields': ('description', 'tags', 'sub_id', 'target_group')}),
-        ('Current status', {
-            'fields': ('actual_device', 'state', 'health')}),
-        ('Results & Failures', {
-            'fields': ('failure_tags', 'failure_comment')}),
+        (
+            "Owner",
+            {
+                "fields": (
+                    "user",
+                    "group",
+                    "submitter",
+                    "is_public",
+                    "visibility",
+                    "viewing_groups",
+                )
+            },
+        ),
+        ("Request", {"fields": ("requested_device_type", "priority", "health_check")}),
+        (
+            "Advanced properties",
+            {"fields": ("description", "tags", "sub_id", "target_group")},
+        ),
+        ("Current status", {"fields": ("actual_device", "state", "health")}),
+        ("Results & Failures", {"fields": ("failure_tags", "failure_comment")}),
     )
-    readonly_fields = ('state', )
-    list_display = ('id', 'state', 'health', 'submitter', 'requested_device_type_name',
-                    'actual_device', 'health_check', 'submit_time', 'start_time', 'end_time')
-    ordering = ['-submit_time']
+    readonly_fields = ("state",)
+    list_display = (
+        "id",
+        "state",
+        "health",
+        "submitter",
+        "requested_device_type_name",
+        "actual_device",
+        "health_check",
+        "submit_time",
+        "start_time",
+        "end_time",
+    )
+    ordering = ["-submit_time"]
 
 
-def disable_health_check_action(modeladmin, request, queryset):  # pylint: disable=unused-argument
+def disable_health_check_action(
+    modeladmin, request, queryset
+):  # pylint: disable=unused-argument
     queryset.update(disable_health_check=False)
 
 
@@ -346,46 +429,52 @@ disable_health_check_action.short_description = "disable health checks"
 
 
 class DeviceTypeAdmin(admin.ModelAdmin):
-
     def architecture_name(self, obj):
         if obj.architecture:
             return obj.architecture
-        return ''
+        return ""
+
     architecture_name.short_description = "arch"
 
     def processor_name(self, obj):
         if obj.processor:
             return obj.processor
-        return ''
+        return ""
+
     processor_name.short_description = "proc"
 
     def cpu_model_name(self, obj):
         if obj.cpu_model:
             return obj.cpu_model
-        return ''
+        return ""
+
     cpu_model_name.short_description = "cpu"
 
     def bit_count(self, obj):
         if obj.bits:
             return obj.bits
-        return ''
+        return ""
+
     bit_count.short_description = "bits"
 
     def list_of_cores(self, obj):
         if obj.core_count:
             return "%s x %s" % (
                 obj.core_count,
-                ','.join([core.name for core in obj.cores.all().order_by('name')]))
-        return ''
+                ",".join([core.name for core in obj.cores.all().order_by("name")]),
+            )
+        return ""
+
     list_of_cores.short_description = "cores"
 
     def get_readonly_fields(self, _, obj=None):
         if obj:  # editing an existing object
-            return self.readonly_fields + ('name',)
+            return self.readonly_fields + ("name",)
         return self.readonly_fields
 
     def health_check_enabled(self, obj):
         return not obj.disable_health_check
+
     health_check_enabled.boolean = True
     health_check_enabled.short_description = "HC enabled"
 
@@ -393,23 +482,51 @@ class DeviceTypeAdmin(admin.ModelAdmin):
         if device_type.health_denominator == DeviceType.HEALTH_PER_JOB:
             return "every %d jobs" % device_type.health_frequency
         return "every %d hours" % device_type.health_frequency
+
     health_check_frequency.short_description = "HC frequency"
 
     actions = [disable_health_check_action]
-    list_filter = ('name', 'display', 'cores',
-                   'architecture', 'processor')
-    list_display = ('name', 'display', 'owners_only', 'health_check_enabled', 'health_check_frequency',
-                    'architecture_name', 'processor_name', 'cpu_model_name',
-                    'list_of_cores', 'bit_count')
-    fieldsets = (
-        ('Properties', {
-            'fields': ('name', 'description', 'display', 'owners_only', 'aliases')}),
-        ('Health checks', {
-            'fields': (('health_frequency', 'health_denominator'), 'disable_health_check')}),
-        ('Meta data', {
-            'fields': ('architecture', 'processor', ('cores', 'core_count'), 'bits', 'cpu_model')})
+    list_filter = ("name", "display", "cores", "architecture", "processor")
+    list_display = (
+        "name",
+        "display",
+        "owners_only",
+        "health_check_enabled",
+        "health_check_frequency",
+        "architecture_name",
+        "processor_name",
+        "cpu_model_name",
+        "list_of_cores",
+        "bit_count",
     )
-    ordering = ['name']
+    fieldsets = (
+        (
+            "Properties",
+            {"fields": ("name", "description", "display", "owners_only", "aliases")},
+        ),
+        (
+            "Health checks",
+            {
+                "fields": (
+                    ("health_frequency", "health_denominator"),
+                    "disable_health_check",
+                )
+            },
+        ),
+        (
+            "Meta data",
+            {
+                "fields": (
+                    "architecture",
+                    "processor",
+                    ("cores", "core_count"),
+                    "bits",
+                    "cpu_model",
+                )
+            },
+        ),
+    )
+    ordering = ["name"]
 
 
 def worker_health_active(ModelAdmin, request, queryset):
@@ -434,20 +551,21 @@ def worker_health_retired(ModelAdmin, request, queryset):
 
 
 worker_health_active.short_description = "Update health of selected workers to Active"
-worker_health_maintenance.short_description = "Update health of selected workers to Maintenance"
+worker_health_maintenance.short_description = (
+    "Update health of selected workers to Maintenance"
+)
 worker_health_retired.short_description = "Update health of selected workers to Retired"
 
 
 class WorkerAdmin(admin.ModelAdmin):
-    list_display = ('hostname', 'state', 'health')
-    readonly_fields = ('state', )
-    ordering = ['hostname']
-    actions = [worker_health_active, worker_health_maintenance,
-               worker_health_retired]
+    list_display = ("hostname", "state", "health")
+    readonly_fields = ("state",)
+    ordering = ["hostname"]
+    actions = [worker_health_active, worker_health_maintenance, worker_health_retired]
 
     def get_readonly_fields(self, _, obj=None):
         if obj:  # editing an existing object
-            return self.readonly_fields + ('hostname',)
+            return self.readonly_fields + ("hostname",)
         return self.readonly_fields
 
     def has_delete_permission(self, request, obj=None):
@@ -455,9 +573,8 @@ class WorkerAdmin(admin.ModelAdmin):
 
 
 class TagLowerForm(forms.ModelForm):
-
     def clean_name(self):
-        name = self.cleaned_data['name']
+        name = self.cleaned_data["name"]
         if name != name.lower():
             raise ValidationError("Tag names are case-insensitive.")
         return name
@@ -465,12 +582,12 @@ class TagLowerForm(forms.ModelForm):
 
 class TagAdmin(admin.ModelAdmin):
     form = TagLowerForm
-    list_display = ('name', 'description')
-    ordering = ['name']
+    list_display = ("name", "description")
+    ordering = ["name"]
 
     def get_readonly_fields(self, _, obj=None):
         if obj:  # editing an existing object
-            return self.readonly_fields + ('name',)
+            return self.readonly_fields + ("name",)
         return self.readonly_fields
 
 
@@ -480,8 +597,9 @@ class NotificationRecipientAdmin(admin.ModelAdmin):
             return obj.email_address
         else:
             return "%s@%s" % (obj.irc_handle, obj.irc_server_name)
-    list_display = ('method', 'handle', 'status')
-    list_filter = ('method', 'status')
+
+    list_display = ("method", "handle", "status")
+    list_filter = ("method", "status")
 
     def has_add_permission(self, request):
         return False
