@@ -1,20 +1,22 @@
+# -*- coding: utf-8 -*-
 # Copyright (C) 2018 Linaro Limited
 #
-# Author: Remi Duraffort <remi.duraffort@linaro.org>
+# Author: Neil Williams <neil.williams@linaro.org>
+#         Remi Duraffort <remi.duraffort@linaro.org>
 #
-# This file is part of LAVA Server.
+# This file is part of LAVA.
 #
-# LAVA Server is free software: you can redistribute it and/or modify
+# LAVA is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License version 3
 # as published by the Free Software Foundation
 #
-# LAVA Server is distributed in the hope that it will be useful,
+# LAVA is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
-# along with LAVA Server.  If not, see <http://www.gnu.org/licenses/>.
+# along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
 from django.conf import settings
 from django.contrib import admin
@@ -26,6 +28,10 @@ admin.site.site_url = "/" + settings.MOUNT_POINT
 
 
 class LogEntryAdmin(admin.ModelAdmin):
+
+    def has_delete_permission(self, request, obj=None):
+        return settings.ALLOW_ADMIN_DELETE
+
     def get_action_flag_display(self, obj):
         if obj.is_addition():
             return "+"
@@ -34,6 +40,7 @@ class LogEntryAdmin(admin.ModelAdmin):
         else:
             return "x"
         return obj.get_action_flag_display()
+
     get_action_flag_display.short_description = "Action"
 
     list_display = ('action_time', 'user', 'content_type', 'object_repr',
