@@ -1,23 +1,26 @@
-# Copyright (C) 2017 Linaro Limited
+# -*- coding: utf-8 -*-
+# Copyright (C) 2017-2018 Linaro Limited
 #
-# Author: Remi Duraffort <remi.duraffort@linaro.org>
+# Author: Neil Williams <neil.williams@linaro.org>
+#         Remi Duraffort <remi.duraffort@linaro.org>
 #
-# This file is part of LAVA Server.
+# This file is part of LAVA.
 #
-# LAVA Server is free software: you can redistribute it and/or modify
+# LAVA is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License version 3
 # as published by the Free Software Foundation
 #
-# LAVA Server is distributed in the hope that it will be useful,
+# LAVA is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
-# along with LAVA Server.  If not, see <http://www.gnu.org/licenses/>.
+# along with LAVA.  If not, see <http://www.gnu.org/licenses/>.
 
 # Created with Django 1.8.18
 
+import contextlib
 import imp
 
 # Import application settings
@@ -45,7 +48,6 @@ INSTALLED_APPS = [
     # Add LAVA dependencies
     'django_tables2',
     'linaro_django_xmlrpc',
-    'google_analytics',
     # Add contrib
     'django.contrib.admin',
     'django.contrib.auth',
@@ -132,14 +134,9 @@ LOGIN_REDIRECT_URL = "/"
 # Automatically install some applications
 available_modules = list()
 for module_name in ["devserver", "django_extensions", "django_openid_auth", "hijack"]:
-    try:
+    with contextlib.suppress(ImportError):
         imp.find_module(module_name)
         INSTALLED_APPS.append(module_name)
-    except ImportError:
-        pass
-
-# Add google analytics model.
-GOOGLE_ANALYTICS_MODEL = True
 
 # General URL prefix
 MOUNT_POINT = ""
@@ -167,13 +164,13 @@ X_FRAME_OPTIONS = 'DENY'
 HTTPS_XML_RPC = True
 
 # Branding support
-BRANDING_ALT = "Linaro logo"
+BRANDING_ALT = "LAVA Software logo"
 BRANDING_ICON = "lava_server/images/logo.png"
-BRANDING_URL = "http://www.linaro.org"
+BRANDING_URL = "https://lavasoftware.org"
 BRANDING_HEIGHT = 22
 BRANDING_WIDTH = 22
-BRANDING_BUG_URL = "/static/docs/v2/development-intro.html#report-a-bug"
-BRANDING_SOURCE_URL = "https://git.linaro.org/lava"
+BRANDING_BUG_URL = "https://git.lavasoftware.org/lava/lava/issues"
+BRANDING_SOURCE_URL = "https://git.lavasoftware.org/lava/lava"
 BRANDING_MESSAGE = ""
 
 # Custom documentation
@@ -199,3 +196,9 @@ AUTH_LDAP_GROUP_TYPE = None
 
 # Debian SSO is of be default
 AUTH_DEBIAN_SSO = None
+
+# Remove Delete buttons in django admin interface
+ALLOW_ADMIN_DELETE = True
+
+# Default callback http timeout in seconds
+CALLBACK_TIMEOUT = 5
