@@ -30,18 +30,10 @@ from django.http import HttpResponse, HttpResponseRedirect
 from django.shortcuts import get_object_or_404, redirect, render
 from django.views.decorators.csrf import csrf_exempt
 
-from linaro_django_xmlrpc.models import (
-    AuthToken,
-    CallContext,
-    Dispatcher,
-    SystemAPI,
-)
+from linaro_django_xmlrpc.models import AuthToken, CallContext, Dispatcher, SystemAPI
 from linaro_django_xmlrpc.forms import AuthTokenForm
 
-from lava_server.bread_crumbs import (
-    BreadCrumb,
-    BreadCrumbTrail,
-)
+from lava_server.bread_crumbs import BreadCrumb, BreadCrumbTrail
 from lava_server.views import index as lava_index
 
 
@@ -62,103 +54,119 @@ def handler(request, mapper, help_view):  # pylint: disable=too-many-return-stat
         raw_data = request.body
         dispatcher = Dispatcher(mapper)
 
-        auth_string = request.META.get('HTTP_AUTHORIZATION')
+        auth_string = request.META.get("HTTP_AUTHORIZATION")
 
         if auth_string is not None:
-            if ' ' not in auth_string:
+            if " " not in auth_string:
                 return HttpResponse("Invalid HTTP_AUTHORIZATION header", status=400)
             scheme, value = auth_string.split(" ", 1)
             if scheme != "Basic":
                 return HttpResponse(
-                    "Unsupported HTTP_AUTHORIZATION header, only Basic scheme is supported", status=400)
+                    "Unsupported HTTP_AUTHORIZATION header, only Basic scheme is supported",
+                    status=400,
+                )
             try:
                 decoded_value = base64.standard_b64decode(value).decode("utf-8")
             except (TypeError, UnicodeDecodeError):
-                return HttpResponse("Corrupted HTTP_AUTHORIZATION header, bad base64 encoding", status=400)
+                return HttpResponse(
+                    "Corrupted HTTP_AUTHORIZATION header, bad base64 encoding",
+                    status=400,
+                )
             try:
                 username, secret = decoded_value.split(":", 1)
             except ValueError:
-                return HttpResponse("Corrupted HTTP_AUTHORIZATION header, no user:pass", status=400)
+                return HttpResponse(
+                    "Corrupted HTTP_AUTHORIZATION header, no user:pass", status=400
+                )
             user = AuthToken.get_user_for_secret(username, secret)
             if user is None:
                 response = HttpResponse("Invalid token", status=401)
-                response['WWW-Authenticate'] = 'Basic realm="XML-RPC Authentication token"'
+                response[
+                    "WWW-Authenticate"
+                ] = 'Basic realm="XML-RPC Authentication token"'
                 return response
         else:
             user = request.user
         result = dispatcher.marshalled_dispatch(raw_data, user, request)
         response = HttpResponse(content_type="application/xml")
         response.write(result)
-        response['Content-length'] = str(len(response.content))
+        response["Content-length"] = str(len(response.content))
         return response
     else:
         return redirect(help_view)
 
 
 @BreadCrumb("API help", parent=lava_index)
-def help(request, mapper, template_name="linaro_django_xmlrpc/api.html"):  # pylint: disable=redefined-builtin
-    context = CallContext(
-        user=None, mapper=mapper, dispatcher=None)
+def help(
+    request, mapper, template_name="linaro_django_xmlrpc/api.html"
+):  # pylint: disable=redefined-builtin
+    context = CallContext(user=None, mapper=mapper, dispatcher=None)
     system = SystemAPI(context)
     if settings.HTTPS_XML_RPC:
         scheme = "https"
     else:
-        scheme = request.META.get('REQUEST_SCHEME', "http")
+        scheme = request.META.get("REQUEST_SCHEME", "http")
     dashboard_methods = []
     scheduler_methods = []
     results_methods = []
     system_methods = []
     for method in system.listMethods():
-        if 'dashboard' in method:
+        if "dashboard" in method:
             dashboard_methods.append(method)
-        elif 'scheduler' in method:
+        elif "scheduler" in method:
             scheduler_methods.append(method)
-        elif 'results' in method:
+        elif "results" in method:
             results_methods.append(method)
         else:
             system_methods.append(method)
     methods = {
-        'dashboard': [
+        "dashboard": [
             {
-                'name': method,
-                'signature': system.methodSignature(method),
-                'help': system.methodHelp(method)
+                "name": method,
+                "signature": system.methodSignature(method),
+                "help": system.methodHelp(method),
             }
             for method in dashboard_methods
         ],
-        'scheduler': [
+        "scheduler": [
             {
-                'name': method,
-                'signature': system.methodSignature(method),
-                'help': system.methodHelp(method)
+                "name": method,
+                "section": method.rsplit(".", 1)[0] if "." in method else "",
+                "signature": system.methodSignature(method),
+                "help": system.methodHelp(method),
             }
             for method in scheduler_methods
         ],
-        'results': [
+        "results": [
             {
-                'name': method,
-                'signature': system.methodSignature(method),
-                'help': system.methodHelp(method)
+                "name": method,
+                "signature": system.methodSignature(method),
+                "help": system.methodHelp(method),
             }
             for method in results_methods
         ],
-        'system': [
+        "system": [
             {
-                'name': method,
-                'signature': system.methodSignature(method),
-                'help': system.methodHelp(method)
+                "name": method,
+                "signature": system.methodSignature(method),
+                "help": system.methodHelp(method),
             }
             for method in system_methods
-        ]}
+        ],
+    }
     domain = Site.objects.get_current().domain
-    return render(request, template_name,
-                  {'methods': methods,
-                   'context_help': ['data-export'],
-                   'bread_crumb_trail': BreadCrumbTrail.leading_to(help),
-                   'site_scheme': scheme,
-                   'site_domain': domain,
-                   'site_url': "{scheme}://{domain}".format(scheme=scheme,
-                                                            domain=domain)})
+    return render(
+        request,
+        template_name,
+        {
+            "methods": methods,
+            "context_help": ["data-export"],
+            "bread_crumb_trail": BreadCrumbTrail.leading_to(help),
+            "site_scheme": scheme,
+            "site_domain": domain,
+            "site_url": "{scheme}://{domain}".format(scheme=scheme, domain=domain),
+        },
+    )
 
 
 @BreadCrumb("API tokens", parent=lava_index)
@@ -167,14 +175,20 @@ def tokens(request):
     """
     List of tokens for an authenticated user
     """
-    token_list = AuthToken.objects.filter(user=request.user).order_by(
-        "last_used_on")
-    unused = AuthToken.objects.filter(user=request.user, last_used_on__isnull=True).count()
-    return render(request, "linaro_django_xmlrpc/tokens.html",
-                  {"token_list": token_list,
-                   "unused": unused,
-                   'bread_crumb_trail': BreadCrumbTrail.leading_to(tokens),
-                   "context_help": ["first_steps"]})
+    token_list = AuthToken.objects.filter(user=request.user).order_by("last_used_on")
+    unused = AuthToken.objects.filter(
+        user=request.user, last_used_on__isnull=True
+    ).count()
+    return render(
+        request,
+        "linaro_django_xmlrpc/tokens.html",
+        {
+            "token_list": token_list,
+            "unused": unused,
+            "bread_crumb_trail": BreadCrumbTrail.leading_to(tokens),
+            "context_help": ["first_steps"],
+        },
+    )
 
 
 @login_required
@@ -188,23 +202,21 @@ def create_token(request):
             form.save(commit=False)
             form.instance.user = request.user
             form.instance.save()
-            return HttpResponseRedirect(
-                reverse("linaro_django_xmlrpc_tokens"))
+            return HttpResponseRedirect(reverse("linaro_django_xmlrpc_tokens"))
     else:
         form = AuthTokenForm()
-    return render(request, "linaro_django_xmlrpc/create_token.html",
-                  {"form": form})
+    return render(request, "linaro_django_xmlrpc/create_token.html", {"form": form})
 
 
 @login_required
 def delete_token(request, object_id):
     token = get_object_or_404(AuthToken, pk=object_id, user=request.user)
-    if request.method == 'POST':
+    if request.method == "POST":
         token.delete()
-        return HttpResponseRedirect(
-            reverse("linaro_django_xmlrpc_tokens"))
-    return render(request, "linaro_django_xmlrpc/authtoken_confirm_delete.html",
-                  {"token": token})
+        return HttpResponseRedirect(reverse("linaro_django_xmlrpc_tokens"))
+    return render(
+        request, "linaro_django_xmlrpc/authtoken_confirm_delete.html", {"token": token}
+    )
 
 
 @login_required
@@ -214,12 +226,12 @@ def edit_token(request, object_id):
         form = AuthTokenForm(request.POST, instance=token)
         if form.is_valid():
             form.save()
-            return HttpResponseRedirect(
-                reverse("linaro_django_xmlrpc_tokens"))
+            return HttpResponseRedirect(reverse("linaro_django_xmlrpc_tokens"))
     else:
         form = AuthTokenForm(instance=token)
-    return render(request, "linaro_django_xmlrpc/edit_token.html",
-                  {"token": token, "form": form})
+    return render(
+        request, "linaro_django_xmlrpc/edit_token.html", {"token": token, "form": form}
+    )
 
 
 @login_required
@@ -228,8 +240,9 @@ def delete_unused_tokens(request):
     if request.method == "POST":
         for token in token_list:
             token.delete()
-        return HttpResponseRedirect(
-            reverse("linaro_django_xmlrpc_tokens")
-        )
-    return render(request, "linaro_django_xmlrpc/tokens.html",
-                  {"token_list": token_list, "context_help": ["lava-tool"]})
+        return HttpResponseRedirect(reverse("linaro_django_xmlrpc_tokens"))
+    return render(
+        request,
+        "linaro_django_xmlrpc/tokens.html",
+        {"token_list": token_list, "context_help": ["lava-tool"]},
+    )
