@@ -22,6 +22,7 @@
 import re
 import subprocess  # nosec - internal
 import os
+import sys
 
 
 # pylint: disable=superfluous-parens,too-many-locals
@@ -37,17 +38,24 @@ def version_tag():
     from that.
     :return: a version string based on the tag and short hash
     """
+    args = ["git", "describe"]
+    if len(sys.argv) == 2:
+        if sys.argv[1] != 'sdist':
+            args.append(sys.argv[1])
     if os.path.exists("./.git/"):
-        pattern = re.compile(r"(?P<tag>.+)-(?P<commits>\d+)-g(?P<hash>[abcdef\d]+)")
+        pattern = re.compile(r"(?P<tag>.+)\.(?P<commits>\d+)\.g(?P<hash>[abcdef\d]+)")
         describe = (
-            subprocess.check_output(["git", "describe"]).strip().decode("utf-8")
-        )  # nosec - internal
+            subprocess.check_output(args)  # nosec - internal
+            .strip()
+            .decode("utf-8")
+            .replace("-", ".")
+        )
         m = pattern.match(describe)
         if m is None:
             return describe
         else:
             d = m.groupdict()
-            return "%s-%04d-g%s" % (d["tag"], int(d["commits"]), d["hash"])
+            return "%s.%04d.g%s" % (d["tag"], int(d["commits"]), d["hash"])
     if os.path.exists('debian/changelog'):
         return subprocess.check_output(('dpkg-parsechangelog', '--show-field',  # nosec - internal
                                         'Version')).strip().decode('utf-8').split('-')[0]
@@ -59,4 +67,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
+    sys.exit(main())
